@@ -3,7 +3,7 @@ package Perinci::Sub::To::CLIDocData;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-27'; # DATE
 our $DIST = 'Perinci-Sub-To-CLIDocData'; # DIST
-our $VERSION = '0.292'; # VERSION
+our $VERSION = '0.293'; # VERSION
 
 use 5.010001;
 use strict;
@@ -447,7 +447,7 @@ sub gen_cli_doc_data_from_meta {
             (keys(%args_prop) || keys(%$common_opts) ? " [options]" : ""). # XXX translatable?
             (@args ? " ".join(" ", @args) : "");
         $clidocdata->{usage_line} = "[[prog]]".
-            (@args ? " ".join(" ", @opts, @args) : "");
+            (@opts+@args ? " ".join(" ", @opts, @args) : "");
     } # GEN_USAGE_LINE
 
     # filter and format examples
@@ -517,7 +517,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.292 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2020-04-27.
+This document describes version 0.293 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2020-04-27.
 
 =head1 SYNOPSIS
 
